deg_min: deg_min

Description Usage Format

Description

Accessory data with the chords present in each scale, with its respective degrees, for the minor cases.

Usage

1

Format

An object of class data.frame with 7 rows and 16 columns.


brunaw/choRds documentation built on Sept. 28, 2020, 4:36 p.m.